PCB Environment: Parameter Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
Parameter Class Reference

## Public Member Functions
| Parameter (const char *name, const std::function< void(const Parameter &)> &commit)
const std::string & | name () const
char | dtype () const
void | set (double)
void | set (int64_t)
void | set (const std::string &)
void | set (const char *s)
void | set (bool)
void | set (PyObject *)
void | setLimits (double def, double min, double max)
void | setLimits (int64_t def, int64_t min, int64_t max)
void | addEnum (const std::string &s)
void | setVisible (bool b)
bool | visible () const
void | init (bool b)
void | init (const std::string &s)
void | init (const char *s)
void | setNotifier (const std::function< void()> &notify)
double | min () const
double | max () const
double | d () const
bool | b () const
const std::string & | s () const
const std::set< std::string > & | getEnum () const
int64_t | i () const
int64_t | as_i () const
double | as_d () const
std::string | as_s () const
bool | as_b () const
template<typename T>
bool | is_a () const

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Parameter.hpp